You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@archiva.apache.org by jv...@apache.org on 2006/10/16 19:30:46 UTC

svn commit: r464576 - /maven/archiva/trunk/maven-meeper/src/bin/synchronize.sh

Author: jvanzyl
Date: Mon Oct 16 10:30:46 2006
New Revision: 464576

URL: http://svn.apache.org/viewvc?view=rev&rev=464576
Log:
o put pauses in at each state to allow for manual checking

Modified:
    maven/archiva/trunk/maven-meeper/src/bin/synchronize.sh

Modified: maven/archiva/trunk/maven-meeper/src/bin/synchronize.sh
URL: http://svn.apache.org/viewvc/maven/archiva/trunk/maven-meeper/src/bin/synchronize.sh?view=diff&rev=464576&r1=464575&r2=464576
==============================================================================
--- maven/archiva/trunk/maven-meeper/src/bin/synchronize.sh (original)
+++ maven/archiva/trunk/maven-meeper/src/bin/synchronize.sh Mon Oct 16 10:30:46 2006
@@ -28,12 +28,15 @@
 echo "REPOCLEAN = $REPOCLEAN"
 echo "M1_M2_REWRITE_RULES = $M1_M2_REWRITE_RULES"
 
-[ "$MODE" = "batch" ] && echo && echo "To continue press any key or hit ^C to quit." && echo
+[ "$MODE" = "batch" ] && echo && echo "Press any key to continue, or hit ^C to quit." && echo
 
 # ------------------------------------------------------------------------
 # Syncopate: the Maven 1.x repository 
 # ------------------------------------------------------------------------
-echo Running Syncopate
+
+[ "$MODE" = "batch" ] && echo && echo "Press any key to run syncopate, or hit ^C to quit." && echo
+
+echo "Running Syncopate"
 
 (
   cd $SYNCOPATE
@@ -45,7 +48,10 @@
 # ------------------------------------------------------------------------
 # Repoclean: converting the Maven 1.x repository to Maven 2.x 
 # ------------------------------------------------------------------------
-echo Running repoclean
+
+[ "$MODE" = "batch" ] && echo && echo "Press any key to run the m1 to m2 conversion, or hit ^C to quit." && echo
+
+echo "Running repoclean"
 
 (
   $REPOCLEAN/sync-repoclean.sh
@@ -56,7 +62,10 @@
 # ------------------------------------------------------------------------
 # Manual fixes
 # ------------------------------------------------------------------------
-echo Removing commons-logging 1.1-dev
+
+[ "$MODE" = "batch" ] && echo && echo "Press any key to run manual fixes, or hit ^C to quit." && echo
+
+echo "Removing commons-logging 1.1-dev"
 
 # hack prevent commons-logging-1.1-dev
 CL=$HOME/repository-staging/to-ibiblio/maven2/commons-logging/commons-logging
@@ -69,7 +78,10 @@
 # ------------------------------------------------------------------------
 # Ibiblio synchronization: sync the central repository to Ibiblio 
 # ------------------------------------------------------------------------
-echo Synchronizing to ibiblio
+
+[ "$MODE" = "batch" ] && echo && echo "Press any key to run the sync to Ibiblio, or hit ^C to quit." && echo
+
+echo "Synchronizing to ibiblio"
 
 (
   cd $SYNC_TOOLS
@@ -81,6 +93,11 @@
 # ------------------------------------------------------------------------
 # Copy the mod_rewrite rules to the Maven 1.x repository
 # ------------------------------------------------------------------------
+
+[ "$MODE" = "batch" ] && echo && echo "Press any key to copy the m1 to m2 rewrite rules, or hit ^C to quit." && echo
+
+echo "Copying rewrite rules into place"
+
 if [ "hostname" == $CENTRAL_HOST ]; then
   cp $M1_M2_REWRITE_RULES $HOME/repository-staging/to-ibiblio/maven/.htaccess
 else
@@ -28,12 +28,15 @@
 
 # ------------------------------------------------------------------------
-# Syncopate: the Maven 1.x repository 
+# Syncopate: Sync the Maven 1.x repositories 
 # ------------------------------------------------------------------------